==> pydantic2_schemaorg-0.1.0-py3-none-any.whl: pydantic2_schemaorg/FoodEstablishment.py <==
from __future__ import annotations

from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from pydantic.v1 import Field
from pydantic.v1 import StrictBool

from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class FoodEstablishment(LocalBusiness):
    """A food-related business.

    See: https://schema.org/FoodEstablishment
    Model depth: 4
    """

    type_: str = Field(default="FoodEstablishment", alias="@type", const=True)
    starRating: list[Rating | str] | Rating | str | None = Field(
        default=None,
        description="An official rating for a lodging business or food establishment, e.g. from national"
        "associations or standards bodies. Use the author property to indicate the rating organization,"
        "e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).",
    )
    servesCuisine: list[str | Text] | str | Text | None = Field(
        default=None,
        description="The cuisine of the restaurant.",
    )
    menu: None | (
        list[AnyUrl | URL | str | Text | Menu] | AnyUrl | URL | str | Text | Menu
    ) = Field(
        default=None,
        description="Either the actual menu as a structured representation, as text, or a URL of the menu.",
    )
    acceptsReservations: None | (
        list[AnyUrl | URL | str | Text | StrictBool | Boolean]
        | AnyUrl
        | URL
        | str
        | Text
        | StrictBool
        | Boolean
    ) = Field(
        default=None,
        description="Indicates whether a FoodEstablishment accepts reservations. Values can be Boolean,"
        "an URL at which reservations can be made or (for backwards compatibility) the strings"
        "```Yes``` or ```No```.",
    )
    hasMenu: None | (
        list[AnyUrl | URL | str | Text | Menu] | AnyUrl | URL | str | Text | Menu
    ) = Field(
        default=None,
        description="Either the actual menu as a structured representation, as text, or a URL of the menu.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Rating import Rating
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Menu import Menu
    from pydantic2_schemaorg.Boolean import Boolean

==> pydantic2_schemaorg-0.1.1-py3-none-any.whl: pydantic2_schemaorg/FoodEstablishment.py <==
from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class FoodEstablishment(LocalBusiness):
    """A food-related business.

    See: https://schema.org/FoodEstablishment
    Model depth: 4
    """

    type_: str = Field(default="FoodEstablishment", alias="@type", const=True)
    starRating: Optional[Union[List[Union["Rating", str]], "Rating", str]] = Field(
        default=None,
        description="An official rating for a lodging business or food establishment, e.g. from national"
        "associations or standards bodies. Use the author property to indicate the rating organization,"
        "e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).",
    )
    servesCuisine: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The cuisine of the restaurant.",
    )
    menu: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Menu"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Menu",
        ]
    ] = Field(
        default=None,
        description="Either the actual menu as a structured representation, as text, or a URL of the menu.",
    )
    acceptsReservations: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", StrictBool, "Boolean"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            StrictBool,
            "Boolean",
        ]
    ] = Field(
        default=None,
        description="Indicates whether a FoodEstablishment accepts reservations. Values can be Boolean,"
        "an URL at which reservations can be made or (for backwards compatibility) the strings"
        "```Yes``` or ```No```.",
    )
    hasMenu: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Menu"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Menu",
        ]
    ] = Field(
        default=None,
        description="Either the actual menu as a structured representation, as text, or a URL of the menu.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Rating import Rating
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Menu import Menu
    from pydantic2_schemaorg.Boolean import Boolean
